.. _contents:

=================
Table of contents
=================

.. toctree::
   :maxdepth: 2

   api
   cli
   authors
   devguide
   changes


==================
Indices and tables
==================

.. only:: builder_html

   * :ref:`genindex`
   * :ref:`search`
   * :ref:`glossary`

.. only:: not builder_html

   * :ref:`glossary`

